pub struct TransformEvent {
pub target_entity: Uid,
pub entity_info: EntityInfo,
pub allow_players: bool,
pub delete_on_failure: bool,
}Fields
target_entity: Uidentity_info: EntityInfoallow_players: boolIf set to false, players wont be transformed unless with a Possessor presence kind
delete_on_failure: boolWhether the entity should be deleted if transforming fails (only applies to non-players)